def return_function(node):
    if node["data"]["value"] == "Train-Test Split":
        return temp_train_test_split(node['data']['parameters'])
    elif node["data"]["value"] == "Train Model":
        return temp_train_model(node['data']['parameters'])

def temp_train_test_split(params):
    parameters = {
        "test_size": params["test_size"],
    }
    return f"training_dataset, test_dataset = huble.sklearn.train_test_split(data=data,parameters={parameters})"


def temp_train_model(params):
    return f"Model = huble.sklearn.train_model(data=data, model=model, column={params['target_column']})"
    


from .functions import fetch_experiment
from .sklearn import generate_file

# {
#   "id": "ad40ca00-4a45-4690-babb-4e6b15348302",
#   "title": "able-air",
#   "pipelineJSON": {
    
#   },
#   "project": {
#     "targetColumn": "Survived",
#     "taskType": "classification"
#   }
# }
def run_experiment(experiment_id,auth_key=''):
  #TODO: Implement auth keys
  experiment = fetch_experiment(experiment_id)
  pipeline = experiment['pipelineJSON']
  project = experiment['project']
  target_column = project['targetColumn']
  task_type = project['taskType']
  try:
    generate_file(pipeline,target_column,task_type)
  except:
    print("Error generating file")
    return



from sklearn.model_selection import train_test_split
import pandas as pd

def train_test_split(**params):
    data = params['data']
    train_dataset, test_dataset = train_test_split(data, test_size=0.33, random_state=42)
    return train_dataset, test_dataset


def train_model(**params):
    data = params['data']
    y = data[(params['column'])]
    X = data.drop(y, axis=1)
    model = params['model']
    Model =  model.fit(X, y)
    return Model